This function quantifies sources of agreement and disagreement between a reference map for time 1, a reference map for time 2 and a simulated map for time 2 to provide meaningful information about the performance of land use change simulations.
AgreementBudget(x, ...)# S4 method for ThreeMapComparison
AgreementBudget(x, ...)
# S4 method for RasterLayer
AgreementBudget(x, ...)
An AgreementBudget object.
a ThreeMapComparison object or RasterLayer
additional arguments to ThreeMapComparison. Only required if x is not a ThreeMapComparison object
The types of agreement and disagreement considered are those descibed in Pontius et al. (2011):
Persistence simulated correctly (agreement)
Persistence simulated as change (disagreement)
Change simulated incorrectly (disagreement)
Change simulated correctly (agreement)
Change simulated as persistence (disagreement)
Pontius Jr, R.G., Peethambaram, S., Castella, J.C. (2011). Comparison of three maps at multiple resolutions: a case study of land change simulation in Cho Don District, Vietnam. Annals of the Association of American Geographers 101(1): 45-62.
AgreementBudget-class,
plot.AgreementBudget, ThreeMapComparison,
FigureOfMerit
## see lulcc-package examples
Run the code above in your browser using DataLab